@extends('admin.layouts.master')

@section('extra_css')
    <link rel="stylesheet" type="text/css" href="/assets/plugins/select2/select2.css"/>
    <link rel="stylesheet" type="text/css"
          href="/assets/plugins/datatables/extensions/Scroller/css/dataTables.scroller.min.css"/>
    <link rel="stylesheet" type="text/css"
          href="/assets/plugins/datatables/extensions/ColReorder/css/dataTables.colReorder.min.css"/>
    <link rel="stylesheet" type="text/css"
          href="/assets/plugins/datatables/plugins/bootstrap/dataTables.bootstrap.css"/>
@stop

@section('extra_js')
    <script type="text/javascript" src="/assets/plugins/select2/select2.min.js"></script>
    <script type="text/javascript" src="/assets/plugins/datatables/media/js/jquery.dataTables.min.js"></script>
    <script type="text/javascript"
            src="/assets/plugins/datatables/extensions/TableTools/js/dataTables.tableTools.min.js"></script>
    <script type="text/javascript"
            src="/assets/plugins/datatables/extensions/ColReorder/js/dataTables.colReorder.min.js"></script>
    <script type="text/javascript"
            src="/assets/plugins/datatables/extensions/Scroller/js/dataTables.scroller.min.js"></script>
    <script type="text/javascript" src="/assets/plugins/datatables/plugins/bootstrap/dataTables.bootstrap.js"></script>
    <script type="text/javascript">
        $(document).ready(function () {
            Metronic.handleTables();
        });
    </script>
@stop

@section('content')

    <h3 class="page-title">
        Posts
        <small>Manage Posts</small>
    </h3>

    <div class="page-bar">
        <ul class="page-breadcrumb">

            <li>
                <a href="/admin">Home</a>
                <i class="fa fa-angle-right"></i>
            </li>

            <li>
                <a href="/admin/posts">Sources</a>
            </li>

        </ul>
    </div>

    <!-- END PAGE HEADER-->
    <!-- BEGIN PAGE CONTENT-->
    <div class="row">
        <div class="col-md-12">
            <!-- BEGIN PORTLET-->
            <div class="portlet box green-meadow">
                <div class="portlet-title">
                    <div class="caption">
                        <i class="icon-puzzle"></i>All Posts
                    </div>
                    <div class="actions">
                        <a href="/admin/posts/create" class="btn red">
                            <i class="fa fa-plus"></i> Create New Post </a>
                    </div>
                </div>

                <figure class="portlet-body">

                    @include('admin.layouts.notify')

                    <table class="table table-striped table-bordered table-hover" id="datatable_advanced">
                        <thead>
                        <tr>
                            <th>ID</th>
                            <th>
                                Featured Image
                            </th>
                            <th>
                                Title
                            </th>
                            <th>
                                Sub Category
                            </th>
                            <th>
                                Source
                            </th>
                            <th>
                                Views
                            </th>
                            <th>
                                Published On
                            </th>
                            <th>
                                Status
                            </th>
                            <th>Edit</th>
                            <th>Delete</th>
                        </tr>
                        </thead>
                        <tbody>
                        @foreach($posts as $post)
                            <tr>
                                <td> {{$post->id}} </td>
                                <td>

                                    @if($post->render_type == \App\Posts::RENDER_TYPE_IMAGE || $post->render_type == \App\Posts::RENDER_TYPE_GALLERY)
                                        <a target="_blank" href="{{$post->featured_image}}"><img
                                                    src="{{$post->featured_image}}" style="width:100px;"/></a>
                                    @endif

                                    @if($post->render_type == \App\Posts::RENDER_TYPE_VIDEO)
                                        VIDEO POST
                                    @endif

                                    @if($post->render_type == \App\Posts::RENDER_TYPE_TEXT)
                                        TEXT POST
                                    @endif

                                </td>
                                <td> {{$post->title}} </td>
                                <td> {{$post->category->title}} </td>

                                @if($post->type == \App\Posts::TYPE_SOURCE)
                                    <td> {{$post->source->channel_title}} </td>
                                @else
                                    <td> MANUAL</td>
                                @endif

                                <td> {{$post->views}} </td>
                                <td> {{$post->created_at->diffForHumans()}} </td>

                                @if($post->status == \App\Posts::STATUS_PUBLISHED)
                                    <td><label class="label label-success label-sm">PUBLISHED</label></td>
                                @endif

                                @if($post->status == \App\Posts::STATUS_HIDDEN)
                                    <td><label class="label label-warning label-sm">HIDDEN</label></td>
                                @endif

                                <td><a href="/admin/posts/edit/{{$post->id}}"
                                       class="btn btn-warning btn-sm">Edit</a>
                                </td>
                                <td><a data-href="/admin/posts/delete/{{$post->id}}" data-toggle="modal"
                                       data-target="#confirm-delete" class="btn btn-danger btn-sm">Delete</a></td>
                            </tr>
                        @endforeach
                        </tbody>
                    </table>

                    <div class="modal fade" id="confirm-delete" tabindex="-1" role="dialog"
                         aria-labelledby="myModalLabel" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-header">
                                    Delete Post ?
                                </div>
                                <div class="modal-body" style="background-color:#FFB848; color:#ffffff;">
                                    <h4><i class="fa fa-exclamation-triangle"></i> Are you sure that you want to delete
                                        this Post ? Deleting posts coming from feed is not permanent it will update
                                        automatically when cron job runs
                                    </h4>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                                    <a class="btn btn-danger btn-ok">Delete</a>
                                </div>
                            </div>
                        </div>
                    </div>

            </div>
        </div>
        <!-- END PORTLET-->
    </div>
    </div>
@stop